import requests
class download:
    Json_video = None
    def api_url(self):
        return "https://ssyoutube.com/api/convert"
		
    def __init__(self, ytURL):
        keys ={'url' : ytURL}
        result = requests.post(url = self.api_url(), params = keys)
        self.Json_video = result.json()
		
    def ShowQuality(self, List = False):
        video = self.Json_video
        if List:
            list_quality = []
            for i in range(len(video['url'])):
                audio = "Yeas"
                try:
                    if video['url'][i]['attr']['class'] != "":
                        audio = video['url'][i]['attr']['class']
                except:
                    audio = "Not specified"
                list_quality.append({'Type' : video['url'][i]['type'], 'Quality' : video['url'][i]['quality'], 'Audio' : audio})
            return list_quality
        else:
            str_quality = ""
            for i in range(len(video['url'])):
                audio = "Yes"
                try:
                    if video['url'][i]['attr']['class'] != "":
                        audio = video['url'][i]['attr']['class']
                except:
                    audio = "Not specified"
                str_quality += f"Type : {video['url'][i]['type']} \t Quality : {video['url'][i]['quality']} \t Audio : {audio}\n"
            return str_quality
			
    def GetLink(self, Tvideo, Qvideo):
        video = self.Json_video
        for i in range(len(video['url'])):
            if  video['url'][i]['type'] == Tvideo and video['url'][i]['quality'] == Qvideo:
                return video['url'][i]['url']
        return "No Result ..."
		
    def InfoVideo(self, List = False):
        video = self.Json_video
        if List:
            list_title = [{'Title' : video['meta']['title'], 'Durition' : video['meta']['duration'], 'Url' : video['meta']['source']}]
            return list_title
        else:
            title = f"Title : {video['meta']['title']}     -     Durition : {video['meta']['duration']}\n"
            title += f"Url : {video['meta']['source']}"
            return title





from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '1.0.10'
DESCRIPTION = 'Downloader YouTube Persian'
LONG_DESCRIPTION = 'This library helps you to convert the Gregorian date to Iranian date and the Iranian date to Gregorian date.'

# Setting up
setup(
    name="YTDPersian",
    version=VERSION,
    author="Erfan Mahigir (Sarzamin Danesh Pishro)",
    author_email="<info@Lssc.ir>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=[],
    keywords=['python', 'download', 'Persian', 'YouTube', 'downloader youtube', 'link download', 'Iranian'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.1",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: Implementation",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)
